# Copyright (c) Bo Peng and the University of Texas MD Anderson Cancer Center
# Distributed under the terms of the 3-clause BSD License.

function [repr] = sos_load_obj (filename)
    a = load(filename)
    repr = a.obj
